searchData={"items":[{"type":"module","title":"TelemetryMetricsSplunk","doc":"`Telemetry.Metrics` reporter for Splunk metrics indexes using the Splunk HTTP Event Collector (HEC).\n\n> **NOTE** All options are required and the order is enforced: `metrics`, `token`, `url`.\n\nYou can start the reporter with the `start_link/1` function:\n\n```elixir\n  alias Telemetry.Metrics\n\n  TelemetryMetricsSplunk.start_link(\n    metrics: [\n      Metrics.summary(\"vm.memory.total\")\n    ],\n    token: \"00000000-0000-0000-0000-000000000000\",\n    url: \"https://example.splunkcloud.com:8088/services/collector\"\n  )\n```\n\nIn production, you should use a Supervisor in your application definition:\n\n```elixir\n  alias Telemetry.Metrics\n\n  children = [\n    {\n      TelemetryMetricsSplunk, [\n        metrics: [\n          Metrics.summary(\"vm.memory.total\")\n        ],\n        token: \"00000000-0000-0000-0000-000000000000\",\n        url: \"https://example.splunkcloud.com:8088/services/collector\"\n      ]\n    }\n  ]\n\n  Supervisor.start_link(children, strategy: :one_for_one)\n```\n\nMetric names are normalized so that calling `:telemetry.execute([:vm, :memory], %{total: 500})` will send a metric named `vm.memory.total.summary`\nif you have a metric defined as `Metrics.summary(\"vm.memory.total\")`.","ref":"TelemetryMetricsSplunk.html"},{"type":"function","title":"TelemetryMetricsSplunk.child_spec/1","doc":"Reporter's child spec.\n\nThis function allows you to start the reporter under a supervisor like this:\n\n```elixir\n  children = [\n    {TelemetryMetricsSplunk, options}\n  ]\n```\n\nSee `start_link/1` for a list of available options.","ref":"TelemetryMetricsSplunk.html#child_spec/1"},{"type":"function","title":"TelemetryMetricsSplunk.handle_event/4","doc":"Handles a telemetry event by normalizing it and sending it to the Splunk HEC.","ref":"TelemetryMetricsSplunk.html#handle_event/4"},{"type":"function","title":"TelemetryMetricsSplunk.start_link/1","doc":"Starts a reporter and links it to the calling process.\n\n```elixir\n  alias Telemetry.Metrics\n\n  TelemetryMetricsSplunk.start_link(\n    metrics: [\n      Metrics.summary(\"vm.memory.total\")\n    ]\n    token: \"00000000-0000-0000-0000-000000000000\",\n    url: \"https://example.splunkcloud.com:8088/services/collector\",\n  )\n```","ref":"TelemetryMetricsSplunk.html#start_link/1"},{"type":"type","title":"TelemetryMetricsSplunk.option/0","doc":"","ref":"TelemetryMetricsSplunk.html#t:option/0"},{"type":"type","title":"TelemetryMetricsSplunk.options/0","doc":"","ref":"TelemetryMetricsSplunk.html#t:options/0"},{"type":"module","title":"TelemetryMetricsSplunk.Hec.Api","doc":"Sends metrics to the Splunk HTTP Event Collector (HEC).\n\n```elixir\nalias TelemetryMetricsSplunk.Hec.Api\n\nmeasurements = %{\n  \"vm.memory.total.summary\" => 500\n}\n\noptions = [\n  token: \"00000000-0000-0000-0000-000000000000\",\n  url: \"https://example.splunkcloud.com:8088/services/collector\"\n]\n\nmetadata = %{\n  \"server\" => \"alpha\"\n}\n\nApi.send(measurements, options, metadata)\n```\n\n> **NOTE** Metadata is optional and gets sent as dimensions.","ref":"TelemetryMetricsSplunk.Hec.Api.html"},{"type":"function","title":"TelemetryMetricsSplunk.Hec.Api.send/3","doc":"Sends metrics to the Splunk HTTP Event Collector (HEC).","ref":"TelemetryMetricsSplunk.Hec.Api.html#send/3"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,48]}}